import org.faceless.graph2.*;
import java.awt.Color;
import java.io.FileOutputStream;
import java.io.IOException;

public class BubbleExample 
{
    public static void main (String args[]) throws IOException
    {
        // Create graph and set up axes
        //
        AxesGraph graph = new AxesGraph();
        graph.getAxis(Axis.BOTTOM).setMinValue(0);
        graph.getAxis(Axis.BOTTOM).setMaxValue(50);
        graph.getAxis(Axis.LEFT).setMinValue(0);
        graph.getAxis(Axis.LEFT).setMaxValue(50);
        graph.setBackWallPaint(null, new Color(194,222,150), Axis.LEFT, Axis.BOTTOM, null);
        
        // Create series and add data and styles
        //
        BubbleSeries bubbles = new BubbleSeries("bubbles");
        
        bubbles.set(10, 10, 4);
        bubbles.setStyle(10,10, new Style(Color.RED));
        
        bubbles.set(5, 43, 5);
        bubbles.set(42, 16, 3);
        
        bubbles.set(30, 25, 10);
        Style s = new Style(Color.YELLOW);
        s.setBorderColor(new Color(67,136,0));
        s.setLineThickness(4);
        bubbles.setStyle (30,25, s);
        
        bubbles.set(20, 35, 7);
        bubbles.setStyle(20,35, new Style(new Color(255,117,205)));
        
        bubbles.set(40, 22, 7);
        Style s2 = new Style(new Color(188,129,226));
        s2.setBorderColor(new Color(250,123,213));
        s2.setLineThickness(2);
        bubbles.setStyle (40,22, s2);
        
        // Add series to graph
        //
        graph.addSeries(bubbles);
        
        // Add some text to the graph and markers to the series
        //
        graph.addText ("Ice Cream Taste Test", new TextStyle("Arial", 20, Color.BLUE));
        graph.getAxis(Axis.BOTTOM).setLabel("Number of Tasters", new TextStyle("Arial", 10, Color.BLACK));
        graph.getAxis(Axis.LEFT).setLabel("Number of Scoops", new TextStyle("Arial", 10, Color.BLACK));
        bubbles.addMarker(new Text("Chocolate", new TextStyle("Arial", 12, Color.DARK_GRAY)),25,30);
        bubbles.addMarker(new Text("Vanilla", new TextStyle("Arial", 12, Color.DARK_GRAY)),17,37);
        bubbles.addMarker(new Text("Cookies 'n Cream", new TextStyle("Arial", 12, Color.DARK_GRAY)),33,22);
        bubbles.addMarker(new Text("Strawberry", new TextStyle("Arial", 12, Color.DARK_GRAY)),6,10);
        bubbles.addMarker(new Text("Lemon", new TextStyle("Arial", 12, Color.DARK_GRAY)),2,43);
        bubbles.addMarker(new Text("Rum 'n' Raisen", new TextStyle("Arial", 12, Color.DARK_GRAY)),37,12);
        bubbles.addMarker(new Text("Circle Width is Popularity", new TextStyle("Times", 14, Color.RED)),25,46);
        
        // Write the file
        //
	ImageOutput image = new ImageOutput(400, 400);
	graph.draw(image);
	FileOutputStream out = new FileOutputStream("BubbleExample.png");
	image.writePNG(out, 0);
        out.close();
    }
}