import org.faceless.graph2.*;
import java.awt.Color;
import java.io.FileOutputStream;
import java.io.IOException;

public class LineBarExample
{
    public static void main (String args[]) throws IOException
    {
        // Create a Bar Series
        //
        BarSeries barseries1 = new BarSeries("bars");
	barseries1.set("apples", 10);
	barseries1.set("bananas", 30);
	barseries1.set("cranberries", 25);
	barseries1.set("dates", 15);
	barseries1.set("eggs", 10);
	barseries1.set("figs", 50);
	barseries1.set("guava", 6);

        // Create a Line Series
        //
        LineSeries lineseries1 = new LineSeries("lines");
	lineseries1.set(0,10);
	lineseries1.set(1,32);
	lineseries1.set(2,18);
	lineseries1.set(3,24);
	lineseries1.set(4,27);
	lineseries1.set(5,32);
	lineseries1.set(6,22);

        // Set the lineseries to use dashed lines
        //
	Style style = new Style(Color.yellow);
	style.setLineDash(new double[] { 5, 5 });
	lineseries1.setStyle(style);

        // Add the two series to the graph, and set a couple of options
        //
        AxesGraph graph = new AxesGraph();
        graph.addSeries(lineseries1);
        graph.addSeries(barseries1);
        graph.setXRotation(30);
        graph.setYRotation(20);

        // Set some labels on the graph
        //
	graph.getAxis(Axis.LEFT).setLabel("Y Axis Label", new TextStyle("Default", 11, Color.black));
	graph.getAxis(Axis.BOTTOM).setLabel("X Axis Label", new TextStyle("Default", 11, Color.black));

        // Create a key using two different fonts, and set on the right
        //
	Key key = new Key(new Style(Color.ORANGE));
	key.addSeries(lineseries1, new TextStyle("Courier", 12, Color.BLACK));
	key.addSeries(barseries1, new TextStyle("Arial", 12, Color.BLUE));
	graph.addKey(key, Align.RIGHT);

        // And write the file out
        //
        ImageOutput image = new ImageOutput(500,500);
        graph.draw(image);
	FileOutputStream out = new FileOutputStream("LineBarExample.png");
	image.writePNG(out, 0);
        out.close();
    }
}
